# -*- coding: utf-8 -*-

# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module defining some informational strings.
"""

from __future__ import unicode_literals

Program = 'eric6'
Version = '17.02.1 (rev. ac8e49751d68)'
VersionOnly = '17.02.1'
Copyright = 'Copyright (c) 2002 - 2017 Detlev Offenbach' \
            ' <detlev@die-offenbachs.de>'
BugAddress = 'eric-bugs@eric-ide.python-projects.org'
FeatureAddress = 'eric-featurerequest@eric-ide.python-projects.org'
Homepage = "https://eric-ide.python-projects.org/index.html"
